@@ -42,5 +42,32 @@ function admin()
 	return $objResponse;
 }
 
+function do_dial($src, $callerid, $dest)
+{
+	require("ami.php");
+	$ami = new AMI();
+
+	$objResponse = new xajaxResponse();
+	if(!$ami->login())
+		return $ami->error;
+
+	if(!$ami->dial($src, $callerid, $dest)) {
+		return $ami->error;
+	}
+	$ami->logout();
+	return;
+}
+
+function dial($dest)
+{
+	$ret = do_dial($_SESSION['ext'], $_SESSION['callerid'], $dest);
+
+	$objResponse = new xajaxResponse();
+	if($ret)
+		$objResponse->alert($ret);
+
+	return $objResponse;
+}
+
 $xajax->processRequest();
 ?>
